@@ -2,8 +2,6 @@ package operator
 
 import (
 	"context"
-	"errors"
-	"fmt"
 	"os"
 	"time"
 
@@ -15,11 +13,15 @@ import (
 	"github.com/openshift/cluster-kube-scheduler-operator/pkg/operator/configobservation/configobservercontroller"
 	"github.com/openshift/cluster-kube-scheduler-operator/pkg/operator/operatorclient"
 	"github.com/openshift/cluster-kube-scheduler-operator/pkg/operator/resourcesynccontroller"
+	"github.com/openshift/cluster-kube-scheduler-operator/pkg/operator/targetconfigcontroller"
+	"github.com/openshift/cluster-kube-scheduler-operator/pkg/operator/v410_00_assets"
 	"github.com/openshift/library-go/pkg/controller/controllercmd"
 	"github.com/openshift/library-go/pkg/operator/genericoperatorclient"
+	"github.com/openshift/library-go/pkg/operator/resource/resourceapply"
 	"github.com/openshift/library-go/pkg/operator/staleconditions"
 	"github.com/openshift/library-go/pkg/operator/staticpod"
 	"github.com/openshift/library-go/pkg/operator/staticpod/controller/revision"
+	"github.com/openshift/library-go/pkg/operator/staticresourcecontroller"
 	"github.com/openshift/library-go/pkg/operator/status"
 	"github.com/openshift/library-go/pkg/operator/v1helpers"
 	apierrors "k8s.io/apimachinery/pkg/api/errors"
@@ -27,10 +29,6 @@ import (
 	"k8s.io/client-go/kubernetes"
 )
 
-const (
-	workQueueKey = "key"
-)
-
 func RunOperator(ctx context.Context, cc *controllercmd.ControllerContext) error {
 	kubeClient, err := kubernetes.NewForConfig(cc.ProtoKubeConfig)
 	if err != nil {
@@ -73,23 +71,32 @@ func RunOperator(ctx context.Context, cc *controllercmd.ControllerContext) error
 		cc.EventRecorder,
 	)
 
-	imagePullSpec, ok := os.LookupEnv("IMAGE")
-	if !ok {
-		return errors.New("environment variable 'IMAGE' is missing")
-	}
-	if len(imagePullSpec) == 0 {
-		return errors.New("environment variable 'IMAGE' can't be empty")
-	}
-	operatorImagePullSpec, ok := os.LookupEnv("OPERATOR_IMAGE")
-	if !ok {
-		return errors.New("environment variable 'OPERATOR_IMAGE' is missing")
-	}
-	if len(operatorImagePullSpec) == 0 {
-		return errors.New("environment variable 'OPERATOR_IMAGE' can't be empty")
-	}
-	targetConfigReconciler := NewTargetConfigReconciler(
-		imagePullSpec,
-		operatorImagePullSpec,
+	staticResourceController := staticresourcecontroller.NewStaticResourceController(
+		"KubeControllerManagerStaticResources",
+		v410_00_assets.Asset,
+		[]string{
+			"v4.1.0/kube-scheduler/ns.yaml",
+			"v4.1.0/kube-scheduler/kubeconfig-cm.yaml",
+			"v4.1.0/kube-scheduler/kubeconfig-cert-syncer.yaml",
+			"v4.1.0/kube-scheduler/leader-election-rolebinding.yaml",
+			"v4.1.0/kube-scheduler/scheduler-clusterrolebinding.yaml",
+			"v4.1.0/kube-scheduler/policyconfigmap-role.yaml",
+			"v4.1.0/kube-scheduler/policyconfigmap-rolebinding.yaml",
+			"v4.1.0/kube-scheduler/svc.yaml",
+			"v4.1.0/kube-scheduler/sa.yaml",
+			"v4.1.0/kube-scheduler/localhost-recovery-client-crb.yaml",
+			"v4.1.0/kube-scheduler/localhost-recovery-sa.yaml",
+			"v4.1.0/kube-scheduler/localhost-recovery-token.yaml",
+		},
+		(&resourceapply.ClientHolder{}).WithKubernetes(kubeClient),
+		operatorClient,
+		cc.EventRecorder,
+	).AddKubeInformers(kubeInformersForNamespaces)
+
+	targetConfigController := targetconfigcontroller.NewTargetConfigController(
+		ctx,
+		os.Getenv("IMAGE"),
+		os.Getenv("OPERATOR_IMAGE"),
 		operatorClient,
 		kubeInformersForNamespaces.InformersFor(operatorclient.TargetNamespace),
 		kubeInformersForNamespaces,
@@ -101,7 +108,7 @@ func RunOperator(ctx context.Context, cc *controllercmd.ControllerContext) error
 
 	// don't change any versions until we sync
 	versionRecorder := status.NewVersionGetter()
-	clusterOperator, err := configClient.ConfigV1().ClusterOperators().Get("kube-scheduler-operator", metav1.GetOptions{})
+	clusterOperator, err := configClient.ConfigV1().ClusterOperators().Get(ctx, "kube-scheduler-operator", metav1.GetOptions{})
 	if err != nil && !apierrors.IsNotFound(err) {
 		return err
 	}
@@ -137,7 +144,7 @@ func RunOperator(ctx context.Context, cc *controllercmd.ControllerContext) error
 		cc.EventRecorder,
 	)
 
-	staleConditions := staleconditions.NewRemoveStaleConditions(
+	staleConditions := staleconditions.NewRemoveStaleConditionsController(
 		[]string{
 			// the static pod operator used to directly set these. this removes those conditions since the static pod operator was updated.
 			// these can be removed in 4.5
@@ -153,15 +160,16 @@ func RunOperator(ctx context.Context, cc *controllercmd.ControllerContext) error
 	configInformers.Start(ctx.Done())
 	dynamicInformers.Start(ctx.Done())
 
-	go staticPodControllers.Run(ctx, 1)
+	go staticPodControllers.Start(ctx)
+	go staticResourceController.Run(ctx, 1)
 	go resourceSyncController.Run(ctx, 1)
-	go targetConfigReconciler.Run(1, ctx.Done())
+	go targetConfigController.Run(1, ctx.Done())
 	go configObserver.Run(ctx, 1)
 	go clusterOperatorStatus.Run(ctx, 1)
 	go staleConditions.Run(ctx, 1)
 
 	<-ctx.Done()
-	return fmt.Errorf("stopped")
+	return nil
 }
 
 // deploymentConfigMaps is a list of configmaps that are directly copied for the current values.  A different actor/controller modifies these.
